aboutsummaryrefslogtreecommitdiff
path: root/src/lua/modules/net/net.cpp
diff options
context:
space:
mode:
authorchai <chaifix@163.com>2018-10-20 16:18:11 +0800
committerchai <chaifix@163.com>2018-10-20 16:18:11 +0800
commitcf68d9f46da1cf20503a7d738da1f43de916004d (patch)
tree5577e44d926deadb15ef5ca145e705eae14636fe /src/lua/modules/net/net.cpp
parente9410bd371fc68169c57d2c52382948a0b083da4 (diff)
*格式化代码
Diffstat (limited to 'src/lua/modules/net/net.cpp')
-rw-r--r--src/lua/modules/net/net.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/lua/modules/net/net.cpp b/src/lua/modules/net/net.cpp
index 37a5862..cc2b8de 100644
--- a/src/lua/modules/net/net.cpp
+++ b/src/lua/modules/net/net.cpp
@@ -4,12 +4,12 @@
#include "lua/common/common.h"
#include "Buffer.h"
-namespace jin
+namespace JinEngine
{
-namespace lua
+namespace Lua
{
- using namespace jin::lua::net;
+ using namespace JinEngine::Lua::Net;
using namespace JinEngine::Net;
static int l_initNetwork(lua_State* L)
@@ -57,7 +57,7 @@ namespace lua
{
int size = luax_checkinteger(L, 1);
Proxy* proxy = (Proxy*)luax_newinstance(L, JIN_NETWORK_BUFFER, sizeof(Proxy));
- net::Buffer* buffer = new net::Buffer(size);
+ Net::Buffer* buffer = new Net::Buffer(size);
proxy->bind(new Ref<Buffer>(buffer, JIN_NETWORK_BUFFER));
return 1;
}
@@ -82,5 +82,5 @@ namespace lua
return 1;
}
-} // lua
-} // jin \ No newline at end of file
+} // Lua
+} // JinEngine \ No newline at end of file